// import { PaperClipIcon } from '@heroicons/vue/solid'
import { defineComponent, toRefs, reactive, onMounted, ref } from 'vue'
import arrow from '@/components/musicLIstItem/images/arrow.png'
import styles from './index.module.less'
import albumItem from '@/components/albumItem'
import videoDetailItem from '@/components/videoDetailItem'
import musicLIstItem from '@/components/musicLIstItem'
import titleDot from './images/titleDot.png'
import hotSearch from '@/components/hotSearch'
import banner from '@/components/banner'
import request from '@/helpers/request'
import 'swiper/css'
import 'swiper/css/navigation'
import 'swiper/css/pagination'
import 'swiper/css/scrollbar'
export default defineComponent({
  name: 'home',
  components: {
    albumItem,
    videoDetailItem,
    musicLIstItem,
    hotSearch,
    banner
  },
  setup() {
    const state = reactive({
      albumList: [],
      videoList: []
    })

    const getAlbumList = async () => {
      try {
        const res = await request.post('/api-website/open/music/album/list', {
          data: {
            albumStatus: 1,
            page: 1,
            rows: 10
          }
        })

        state.albumList = res.data.rows
      } catch (e) {
        console.log(e)
      }
    }
    const getVideoList = async () => {
      try {
        const res = await request.post(
          '/api-website/open/videoLessonGroup/page',
          {
            data: {
              albumStatus: 'PASS',
              page: 1,
              rows: 6
            }
          }
        )

        state.videoList = res.data.rows
      } catch (e) {
        console.log(e)
      }
    }

    onMounted(() => {
      getAlbumList()
      getVideoList()
    })
    return () => (
      <div>
        <banner />
        <div class="bg-white">
          <div class={styles.w1200}>
            <div class={styles.section}>
              <div class={styles.titleWrap}>
                <img src={titleDot} class={styles.dotImg} alt="" />
                <h4>热门专辑</h4>
                <img src={titleDot} class={styles.dotImg} alt="" />
              </div>
              <hotSearch></hotSearch>
              <div class={styles.albumList}>
                {state.albumList.map(item => {
                  return <albumItem detail={item}></albumItem>
                })}
              </div>
            </div>
          </div>
        </div>
        <div>
          <div class={styles.w1200}>
            <div class={styles.section}>
              <div class={styles.titleWrap}>
                <img src={titleDot} class={styles.dotImg} alt="" />
                <h4>精品视频课</h4>
                <img src={titleDot} class={styles.dotImg} alt="" />
              </div>
              <div class={styles.videoNav}>
                <h5>精品视频课</h5>
                <div class={styles.wrapRight}>
                  <span>更多</span>
                  <img class={styles.arrow} src={arrow} alt="" />
                </div>
              </div>
              <div class={styles.videoList}>
                {state.videoList.map(item => {
                  return <videoDetailItem detail={item}></videoDetailItem>
                })}
              </div>
            </div>

            {/* <musicLIstItem></musicLIstItem> */}
          </div>
        </div>
      </div>
    )
  }
})
